==> nova_25.0.0.orig.tar.gz: nova-25.0.0/nova/policies/shelve.py <==
# Copyright 2016 Cloudbase Solutions Srl
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_policy import policy

from nova.policies import base


POLICY_ROOT = 'os_compute_api:os-shelve:%s'


shelve_policies = [
    policy.DocumentedRuleDefault(
        name=POLICY_ROOT % 'shelve',
        check_str=base.PROJECT_MEMBER,
        description="Shelve server",
        operations=[
            {
                'method': 'POST',
                'path': '/servers/{server_id}/action (shelve)'
            }
        ],
        scope_types=['project']),
    policy.DocumentedRuleDefault(
        name=POLICY_ROOT % 'unshelve',
        check_str=base.PROJECT_MEMBER,
        description="Unshelve (restore) shelved server",
        operations=[
            {
                'method': 'POST',
                'path': '/servers/{server_id}/action (unshelve)'
            }
        ],
        scope_types=['project']),
    policy.DocumentedRuleDefault(
        name=POLICY_ROOT % 'shelve_offload',
        check_str=base.PROJECT_ADMIN,
        description="Shelf-offload (remove) server",
        operations=[
            {
                'method': 'POST',
                'path': '/servers/{server_id}/action (shelveOffload)'
            }
        ],
        scope_types=['project']),
]


def list_rules():
    return shelve_policies

==> nova_29.2.0.orig.tar.gz: nova-29.2.0/nova/policies/shelve.py <==
# Copyright 2016 Cloudbase Solutions Srl
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_policy import policy

from nova.policies import base


POLICY_ROOT = 'os_compute_api:os-shelve:%s'


shelve_policies = [
    policy.DocumentedRuleDefault(
        name=POLICY_ROOT % 'shelve',
        check_str=base.PROJECT_MEMBER_OR_ADMIN,
        description="Shelve server",
        operations=[
            {
                'method': 'POST',
                'path': '/servers/{server_id}/action (shelve)'
            }
        ],
        scope_types=['project']),
    policy.DocumentedRuleDefault(
        name=POLICY_ROOT % 'unshelve',
        check_str=base.PROJECT_MEMBER_OR_ADMIN,
        description="Unshelve (restore) shelved server",
        operations=[
            {
                'method': 'POST',
                'path': '/servers/{server_id}/action (unshelve)'
            }
        ],
        scope_types=['project']),
    policy.DocumentedRuleDefault(
        name=POLICY_ROOT % 'unshelve_to_host',
        check_str=base.ADMIN,
        description="Unshelve (restore) shelve offloaded server to a "
                    "specific host",
        operations=[
            {
                'method': 'POST',
                'path': '/servers/{server_id}/action (unshelve)'
            }
        ],
        scope_types=['project']),
    policy.DocumentedRuleDefault(
        name=POLICY_ROOT % 'shelve_offload',
        check_str=base.ADMIN,
        description="Shelf-offload (remove) server",
        operations=[
            {
                'method': 'POST',
                'path': '/servers/{server_id}/action (shelveOffload)'
            }
        ],
        scope_types=['project']),
]


def list_rules():
    return shelve_policies
